@@ -27,12 +27,13 @@ class Session(requests.Session):
     Some useful helper methods and object wrappings have been added.
     """
 
-    def __init__(self, webdriver_path=None, browser=None, default_timeout=5, webdriver_options={}, driver=None):
+    def __init__(self, webdriver_path=None, browser=None, default_timeout=5, webdriver_options={}, driver=None, driver_class=None):
         super(Session, self).__init__()
         self.webdriver_path = webdriver_path
         self.default_timeout = default_timeout
         self.webdriver_options = webdriver_options
         self._driver = driver
+        self._driver_class = driver_class
         self._last_requests_url = None
 
         if self._driver is None:
@@ -114,7 +115,13 @@ class Session(requests.Session):
             prefs = self.webdriver_options['prefs']
             chrome_options.add_experimental_option('prefs', prefs)
 
+        experimental_options = self.webdriver_options.get('experimental_options')
+        if isinstance(experimental_options, dict):
+            for name, value in experimental_options.items():
+                chrome_options.add_experimental_option(name, value)
+
         # Create driver process
+        RequestiumChrome = type('RequestiumChrome', (DriverMixin, self._driver_class or webdriver.Chrome), {})
         return RequestiumChrome(self.webdriver_path,
                                 options=chrome_options,
                                 default_timeout=self.default_timeout)
@@ -194,14 +201,14 @@ class RequestiumResponse(object):
         self.__class__ = type(response.__class__.__name__,
                               (self.__class__, response.__class__),
                               response.__dict__)
-        self._response = response
-        self._selector = None
 
     @property
     def selector(self):
-        if self._selector is None:
-            self._selector = Selector(text=self._response.text)
-        return self._selector
+        """Returns the response text in a Selector
+
+        We re-parse the text on each xpath, css, re call in case the encoding has changed.
+        """
+        return Selector(text=self.text)
 
     def xpath(self, *args, **kwargs):
         return self.selector.xpath(*args, **kwargs)
@@ -448,7 +455,3 @@ def _ensure_click(self):
 
 class RequestiumPhantomJS(DriverMixin, webdriver.PhantomJS):
     pass
-
-
-class RequestiumChrome(DriverMixin, webdriver.Chrome):
-    pass
